'''

copy_paste_with_inputs v1.0

Copyright 2021 Sebastian Schütt

https://www.splitthediff.com

'''

import nuke

def copy_with_inputs():

    copy_nodes = nuke.selectedNodes()

    # checking if there is a node selection
    if len(copy_nodes) == 0:
        nuke.message('No node selected.')
    else:

        for node in copy_nodes:
            collected_dependencies = []
            # adding temp user knobs
            temp_user_tab = nuke.Tab_Knob('temp', 'Temp')
            temp_user_knob = nuke.Multiline_Eval_String_Knob('dependencies', 'Dependencies')
            node.addKnob(temp_user_tab)
            node.addKnob(temp_user_knob)

            # checking for input connections and storing the names of the connected nodes in a list
            for i in range(node.inputs()):
                try:
                    input_node = node.input(i).name()
                except:
                    input_node = "none"
                collected_dependencies.append(input_node)
                separator = ","

            # converting the list into a string by using the join method
            node.knob('dependencies').setValue(separator.join(collected_dependencies))

        nuke.nodeCopy('%clipboard%')

        # removing the temp user knobs
        for node in copy_nodes:
            knobs = node.knobs()
            node.removeKnob(knobs['dependencies'])
            node.removeKnob(knobs['temp'])


def paste_with_inputs():

    nuke.nodePaste('%clipboard%')
    paste_nodes = nuke.selectedNodes()

    for node in paste_nodes:
        # checking if the temp user knobs exist
        if node.knob('dependencies'):
            # reading in the stored node dependencies
            collected_dependencies = node.knob('dependencies').getValue().split(",")

            # iterating over the dependencies of each pasted node and setting the connection
            for i, x in enumerate(collected_dependencies):
                if not node.input(i):
                    node.setInput(i, nuke.toNode(x))

            # removing the temp user knobs
            knobs = node.knobs()
            node.removeKnob(knobs['dependencies'])
            node.removeKnob(knobs['temp'])

        else:
            continue
